diff --git a/doc/doxygen/modules.txt b/doc/doxygen/modules.txt
index f6dacdd21e7898262b7f489ea81a6f269402e2af..d951836a865386f31f83389845fceaf3c6e049e6 100644
--- a/doc/doxygen/modules.txt
+++ b/doc/doxygen/modules.txt
@@ -178,18 +178,6 @@
      * \brief Single-phase Navier-Stokes flow
      * \copydetails ./freeflow/navierstokes/model.hh
      */
-    /*!
-     * \ingroup FreeflowModels
-     * \defgroup FreeflowNCModel Compositional
-     * \brief Single-phase multi-component free-flow flow
-     * \copydetails ./freeflow/compositional/navierstokesncmodel.hh
-     */
-    /*!
-     * \ingroup FreeflowModels
-     * \defgroup NavierStokesNIModel nonisothermal
-     * \brief An energy equation adaptor for isothermal Navier-Stokes models
-     * \copydetails ./freeflow/nonisothermal/model.hh
-     */
     /*!
      * \ingroup FreeflowModels
      * \defgroup RANSModel Reynolds-Averaged Navier-Stokes
@@ -216,10 +204,37 @@
          */
     /*!
      * \ingroup FreeflowModels
-     * \defgroup RANSNCModel Reynolds-Averaged Navier-Stokes nc
-     * \brief Single-phase multi-component Reynolds-Averaged Navier-Stokes flow
-     * \copydetails ./freeflow/ransnc/model.hh
+     * \defgroup FreeflowNCModel Compositional
+     * \brief Single-phase multi-component free-flow flow models
      */
+      /*!
+       * \ingroup FreeflowNCModel
+       * \defgroup NavierStokesNCModel Compositional Navier-Stokes
+       * \brief Single-phase multi-component Navier-Stokes flow
+       * \copydetails ./freeflow/compositional/navierstokesncmodel.hh
+       */
+      /*!
+       * \ingroup FreeflowNCModel
+       * \defgroup RANSNCModel Compositional Reynolds-Averaged Navier-Stokes
+       * \brief Single-phase multi-component Reynolds-Averaged Navier-Stokes flow
+       * \copydetails ./freeflow/ransnc/model.hh
+       */
+    /*!
+     * \ingroup FreeflowModels
+     * \defgroup FreeflowNIModel Nonisothermal
+     * \brief An energy equation adaptor for isothermal free-flow models
+     * \copydetails ./freeflow/nonisothermal/model.hh
+     */
+      /*!
+       * \ingroup FreeflowNIModel
+       * \defgroup NavierStokesNIModel Nonisothermal Navier-Stokes
+       * \brief An energy equation adaptor for isothermal Navier-Stokes models
+       */
+      /*!
+       * \ingroup FreeflowNIModel
+       * \defgroup RANSNIModel Nonisothermal Reynolds-Averaged Navier-Stokes
+       * \brief An energy equation adaptor for isothermal Reynolds-Averaged Navier-Stokes models
+       */
 
 /* ***************** Benchmarks and Tests ******************/
 /*!
diff --git a/dumux/freeflow/compositional/navierstokesncmodel.hh b/dumux/freeflow/compositional/navierstokesncmodel.hh
index 4c1b47d9fd920766858b6325ff0539d84b520ea3..cc5a30b6f40b628071f39291439ff8a667a01f7c 100644
--- a/dumux/freeflow/compositional/navierstokesncmodel.hh
+++ b/dumux/freeflow/compositional/navierstokesncmodel.hh
@@ -52,7 +52,7 @@
 #include <dumux/freeflow/navierstokes/model.hh>
 #include <dumux/freeflow/nonisothermal/model.hh>
 #include <dumux/freeflow/nonisothermal/indices.hh>
-#include <dumux/freeflow/nonisothermal/vtkoutputfields.hh>
+#include <dumux/freeflow/nonisothermal/navierstokesnivtkoutputfields.hh>
 #include <dumux/discretization/fickslaw.hh>
 #include <dumux/discretization/fourierslaw.hh>
 
@@ -217,7 +217,7 @@ private:
     static constexpr bool useMoles = GET_PROP_VALUE(TypeTag, UseMoles);
     using IsothermalModelTraits = NavierStokesNCModelTraits<dim, numComponents, phaseIdx, replaceCompEqIdx, useMoles>;
 public:
-    using type = NavierStokesNIModelTraits<IsothermalModelTraits>;
+    using type = FreeflowNIModelTraits<IsothermalModelTraits>;
 };
 
 //! The non-isothermal vtk output fields
diff --git a/dumux/freeflow/navierstokes/model.hh b/dumux/freeflow/navierstokes/model.hh
index ae26d70ea30f98507b486f88ee3dc92094d2ee7c..e26d38e51c301921c2b1920ec50695c4cc75147c 100644
--- a/dumux/freeflow/navierstokes/model.hh
+++ b/dumux/freeflow/navierstokes/model.hh
@@ -52,7 +52,7 @@
 #include <dumux/freeflow/properties.hh>
 #include <dumux/freeflow/nonisothermal/model.hh>
 #include <dumux/freeflow/nonisothermal/indices.hh>
-#include <dumux/freeflow/nonisothermal/vtkoutputfields.hh>
+#include <dumux/freeflow/nonisothermal/navierstokesnivtkoutputfields.hh>
 
 #include "localresidual.hh"
 #include "volumevariables.hh"
@@ -215,7 +215,7 @@ private:
     static constexpr int dim = GridView::dimension;
     using IsothermalTraits = NavierStokesModelTraits<dim>;
 public:
-    using type = NavierStokesNIModelTraits<IsothermalTraits>;
+    using type = FreeflowNIModelTraits<IsothermalTraits>;
 };
 
 //! The specific non-isothermal vtk output fields
diff --git a/dumux/freeflow/nonisothermal/CMakeLists.txt b/dumux/freeflow/nonisothermal/CMakeLists.txt
index 1f1856fa57efc0aa6e98aec8bbe11e7b832f9165..343041b7e53de72b37f34f61457551a8386b12b7 100644
--- a/dumux/freeflow/nonisothermal/CMakeLists.txt
+++ b/dumux/freeflow/nonisothermal/CMakeLists.txt
@@ -3,5 +3,6 @@
 install(FILES
 indices.hh
 model.hh
-vtkoutputfields.hh
+navierstokesnivtkoutputfields.hh
+ransnivtkoutputfields.hh
 DESTINATION ${CMAKE_INSTALL_INCLUDEDIR}/dumux/freeflow/nonisothermal)
diff --git a/dumux/freeflow/nonisothermal/indices.hh b/dumux/freeflow/nonisothermal/indices.hh
index 5e09db53300558f5fb8cf6e6400c237ea3137bb9..42d9edf3649d4616fa14ab22c13ef8729bb087e7 100644
--- a/dumux/freeflow/nonisothermal/indices.hh
+++ b/dumux/freeflow/nonisothermal/indices.hh
@@ -18,23 +18,23 @@
  *****************************************************************************/
 /*!
  * \file
- * \ingroup NavierStokesNIModel
- * \copydoc Dumux::NavierStokesNonIsothermalIndices
+ * \ingroup FreeflowNIModel
+ * \copydoc Dumux::FreeflowNonIsothermalIndices
  */
-#ifndef DUMUX_NAVIERSTOKES_NI_INDICES_HH
-#define DUMUX_NAVIERSTOKES_NI_INDICES_HH
+#ifndef DUMUX_FREEFLOW_NI_INDICES_HH
+#define DUMUX_FREEFLOW_NI_INDICES_HH
 
 namespace Dumux {
 
 /*!
- * \ingroup NavierStokesNIModel
+ * \ingroup FreeflowNIModel
  * \brief Indices for the non-isothermal Navier-Stokes model.
  *
  * \tparam IsothermalIndices The isothermal indices class
  * \tparam numEq the number of equations of the non-isothermal model
  */
 template <class IsothermalIndices, int numEq>
-class NavierStokesNonIsothermalIndices : public IsothermalIndices
+class FreeflowNonIsothermalIndices : public IsothermalIndices
 {
 public:
     static constexpr int energyBalanceIdx = numEq - 1;
diff --git a/dumux/freeflow/nonisothermal/vtkoutputfields.hh b/dumux/freeflow/nonisothermal/navierstokesnivtkoutputfields.hh
similarity index 100%
rename from dumux/freeflow/nonisothermal/vtkoutputfields.hh
rename to dumux/freeflow/nonisothermal/navierstokesnivtkoutputfields.hh
diff --git a/dumux/freeflow/nonisothermal/ransvtkoutputfields.hh b/dumux/freeflow/nonisothermal/ransnivtkoutputfields.hh
similarity index 100%
rename from dumux/freeflow/nonisothermal/ransvtkoutputfields.hh
rename to dumux/freeflow/nonisothermal/ransnivtkoutputfields.hh
diff --git a/dumux/freeflow/rans/model.hh b/dumux/freeflow/rans/model.hh
index a0830144df996ea2df642e77c1d514e028511bea..fc511bbebe87b58c1ff0f47b85c8e8cc3acbafee 100644
--- a/dumux/freeflow/rans/model.hh
+++ b/dumux/freeflow/rans/model.hh
@@ -39,7 +39,7 @@
 
 #include <dumux/common/properties.hh>
 #include <dumux/freeflow/navierstokes/model.hh>
-#include <dumux/freeflow/nonisothermal/ransvtkoutputfields.hh>
+#include <dumux/freeflow/nonisothermal/ransnivtkoutputfields.hh>
 
 #include "vtkoutputfields.hh"
 
@@ -91,7 +91,7 @@ private:
 
     using IsothermalTraits = NavierStokesModelTraits<dim>;
 public:
-    using type = NavierStokesNIModelTraits<IsothermalTraits>;
+    using type = FreeflowNIModelTraits<IsothermalTraits>;
 };
 
 //! The specific non-isothermal vtk output fields
diff --git a/dumux/freeflow/ransnc/model.hh b/dumux/freeflow/ransnc/model.hh
index 3261392afe4f6a0cc3de0e9a57b5088c5028912d..372747753b12ba250f1da5dcde0b90428cf713c6 100644
--- a/dumux/freeflow/ransnc/model.hh
+++ b/dumux/freeflow/ransnc/model.hh
@@ -54,7 +54,7 @@
 
 #include <dumux/common/properties.hh>
 #include <dumux/freeflow/compositional/navierstokesncmodel.hh>
-#include <dumux/freeflow/nonisothermal/ransvtkoutputfields.hh>
+#include <dumux/freeflow/nonisothermal/ransnivtkoutputfields.hh>
 #include <dumux/freeflow/rans/zeroeq/volumevariables.hh>
 
 #include "indices.hh"
diff --git a/dumux/freeflow/nonisothermal/model.hh b/dumux/freeflow/nonisothermal/model.hh
index ef2626da3d24984535fc16b7618977c581c5a8ea..29c083ec88cc8acb2495033c981ae72bdd3daee8 100644
--- a/dumux/freeflow/nonisothermal/model.hh
+++ b/dumux/freeflow/nonisothermal/model.hh
@@ -18,9 +18,9 @@
  *****************************************************************************/
 /*!
  * \file
- * \ingroup NavierStokesNIModel
+ * \ingroup FreeflowNIModel
  *
- * \brief A single-phase, non-isothermal Navier-Stokes model
+ * \brief A single-phase, non-isothermal free-flow model
  *
  * In addition to the momentum and mass/mole balance equations, this model also solves the <B> energy balance equation </B>:
  * \f[
@@ -40,28 +40,28 @@
  * \f[ \lambda_\text{t} = \frac{\nu_\text{t} \varrho c_\text{p}}{\mathrm{Pr}_\text{t}} \f]
  */
 
-#ifndef DUMUX_STAGGERED_NI_MODEL_HH
-#define DUMUX_STAGGERED_NI_MODEL_HH
+#ifndef DUMUX_FREEFLOW_NI_MODEL_HH
+#define DUMUX_FREEFLOW_NI_MODEL_HH
 
 #include "indices.hh"
 
 namespace Dumux {
 
 /*!
  * \ingroup NavierStokesNIModel
  * \brief Specifies a number properties of non-isothermal free flow
  *        flow models based on the specifics of a given isothermal model.
  * \tparam IsothermalTraits Model traits of the isothermal model
  */
 template<class IsothermalTraits>
-struct NavierStokesNIModelTraits : public IsothermalTraits
+struct FreeflowNIModelTraits : public IsothermalTraits
 {
     //! We solve for one more equation, i.e. the energy balance
     static constexpr int numEq() { return IsothermalTraits::numEq()+1; }
     //! We additionally solve for the equation balance
     static constexpr bool enableEnergyBalance() { return true; }
     //! the indices
-    using Indices = NavierStokesNonIsothermalIndices<typename IsothermalTraits::Indices, numEq()>;
+    using Indices = FreeflowNonIsothermalIndices<typename IsothermalTraits::Indices, numEq()>;
 };
 
 } // end  namespace Dumux
@@ -40,28 +40,28 @@
 
 /*!
- * \ingroup NavierStokesNIModel
- * \brief Specifies a number properties of non-isothermal free flow
+ * \ingroup FreeflowNIModel
+ * \brief Specifies a number properties of non-isothermal free-flow
  *        flow models based on the specifics of a given isothermal model.
  * \tparam IsothermalTraits Model traits of the isothermal model